@@ -13,6 +13,7 @@ from pathlib import Path
 import time
 import subprocess
 from typer.models import OptionInfo
+from urllib.parse import urlparse, urljoin
 
 app = typer.Typer(help="Spark Analyzer Configuration Tool")
 console = Console()
@@ -74,6 +75,75 @@ def test_history_server_url(url: str) -> bool:
         )
         return False
 
+def parse_databricks_url(url: str) -> tuple[str, str]:
+    from urllib.parse import urlparse, urljoin
+    
+    if '?' in url:
+        url = url.split('?')[0]
+    
+    parsed = urlparse(url)
+    
+    path_components = parsed.path.split('/')
+    
+    filtered_components = [comp for comp in path_components if comp and comp != 'compute']
+    
+    truncated_components = []
+    for comp in filtered_components:
+        truncated_components.append(comp)
+        if comp.startswith('driver-'):
+            break
+    
+    clean_path = '/' + '/'.join(truncated_components)
+
+    base_url = f"{parsed.scheme}://{parsed.netloc}{clean_path}"
+    
+    if base_url.endswith('/'):
+        base_url = base_url[:-1]
+    
+    api_url = f"{base_url}/api/v1"
+    
+    return base_url, api_url
+
+def extract_databricks_app_id(url: str) -> Optional[str]:
+    from urllib.parse import urlparse
+    
+    if '?' in url:
+        url = url.split('?')[0]
+    
+    parsed = urlparse(url)
+    
+    path_components = parsed.path.split('/')
+    
+    filtered_components = [comp for comp in path_components if comp and comp != 'compute']
+    
+    if len(filtered_components) >= 3 and filtered_components[0] == 'sparkui':
+        app_id = filtered_components[1]
+        if '-' in app_id and app_id.replace('-', '').replace('_', '').isalnum():
+            return app_id
+    
+    return None
+
+def extract_databricks_driver_id(url: str) -> Optional[str]:
+    from urllib.parse import urlparse
+    
+    if '?' in url:
+        url = url.split('?')[0]
+    
+    parsed = urlparse(url)
+    
+    path_components = parsed.path.split('/')
+    
+    filtered_components = [comp for comp in path_components if comp and comp != 'compute']
+    
+    if len(filtered_components) >= 3 and filtered_components[0] == 'sparkui':
+        for comp in filtered_components:
+            if comp.startswith('driver-'):
+                driver_id = comp[7:]
+                if driver_id.isdigit():
+                    return driver_id
+    
+    return None
+
 @app.callback(invoke_without_command=True)
 def callback(ctx: typer.Context):
     """Spark Analyzer Configuration Tool."""
@@ -129,7 +199,7 @@ def configure(
     console.print("")
     console.print("[bold blue]Connection Mode:[/bold blue]")
     console.print("1) Local mode (direct connection to Spark History Server)")
-    console.print("2) Browser mode (connects through browser cookies)")
+    console.print("2) Browser mode (connects through browser cookies for EMR, Databricks, or other web-based applications)")
     
     while True:
         connection_mode = Prompt.ask(
@@ -186,23 +256,65 @@ def configure(
             # Test connection
             if test_history_server_url(history_server_url):
                 break
-    else:
+    elif connection_mode == "2":
         console.print("")
         console.print("[bold blue]Spark History Server URL:[/bold blue]")
-        console.print("Enter the full URL to your Spark History Server.")
+        console.print("Enter the full URL to your Spark History Server or Databricks Spark UI.")
         console.print("Examples:")
-        console.print("  - Standard: https://your-spark-history-server-url/")
+        console.print("  - Standard Spark History Server: https://your-spark-history-server-url/")
         console.print("  - Port forwarded: https://your-spark-history-server-url/path-to-history-server")
-        console.print("  - If '/api/v1' is part of your URL: https://your-spark-history-server-url/path-to-history-server/api/v1")
+        console.print("  - Databricks: Copy the entire link from 'Open in new tab' in Spark UI")
+        console.print("")
         
         while True:
             history_server_url = Prompt.ask(
-                "\nEnter Spark History Server URL",
-                default="https://your-spark-history-server-url"
+                "\nEnter Spark History Server or Databricks Spark UI URL"
             )
             if not history_server_url:
-                console.print("[red]History Server URL is required for browser mode.[/red]")
+                console.print("")
+                console.print("[red]Error: URL is required for browser mode.[/red]")
+                console.print("Please enter a valid Spark History Server or Databricks Spark UI URL.")
+                console.print("")
                 continue
+            
+            # Check if it's a Databricks URL and provide specific guidance
+            if "databricks.com" in history_server_url or "azuredatabricks.net" in history_server_url:
+                if "sparkui" not in history_server_url:
+                    console.print("")
+                    console.print("[yellow]⚠️  Databricks URL detected but doesn't contain 'sparkui'[/yellow]")
+                    console.print("For Databricks, you need to copy the link from the Spark UI:")
+                    console.print("1. Go to your Databricks job/application")
+                    console.print("2. Click on the Spark UI link")
+                    console.print("3. Right-click on 'Open in new tab' and copy the link address")
+                    console.print("4. The URL should contain '/sparkui/' in the path")
+                    console.print("")
+                    if not Confirm.ask("Do you want to continue with this URL anyway?"):
+                        continue
+            
+            # Validate URL format
+            if not history_server_url.startswith(("http://", "https://")):
+                console.print("")
+                console.print("[red]Error: URL must start with http:// or https://[/red]")
+                console.print("Please enter a valid URL.")
+                console.print("")
+                continue
+            
+            if ("databricks.com" in history_server_url or "azuredatabricks.net" in history_server_url) and "sparkui" in history_server_url:
+                try:
+                    base_url, api_url = parse_databricks_url(history_server_url)
+                    history_server_url = api_url
+                except Exception as e:
+                    console.print("")
+                    console.print(f"[red]Error parsing Databricks URL: {str(e)}[/red]")
+                    console.print("Please check the URL format and try again.")
+                    console.print("")
+                    continue
+            else:
+                history_server_url = history_server_url.rstrip("/")
+                if not history_server_url.endswith("/api/v1"):
+                    history_server_url = f"{history_server_url}/api/v1"
+                    console.print(f"[yellow]Note: Adding /api/v1 to the URL for API access: {history_server_url}[/yellow]")
+            
             break
     
     # Create config file
@@ -217,18 +329,37 @@ def configure(
     
     # Handle browser mode cookies
     if connection_mode == "2":
-        cookies_file = config_dir / "raw_cookies.txt"
-        console.print("")
-        console.print("[bold blue]Browser Cookie Setup:[/bold blue]")
-        console.print("For browser mode, you need to copy cookies from your browser.")
-        console.print("")
-        console.print("Steps to get cookies:")
-        console.print("1. Open the Spark History Server in your browser")
-        console.print("2. Open developer tools (F12 or right-click > Inspect)")
-        console.print("3. Go to the Network tab and click on any request")
-        console.print("4. Find the 'Cookie' header in the Request Headers")
-        console.print("5. Copy the entire cookie string")
-        console.print("")
+        is_databricks = ("databricks.com" in history_server_url or "azuredatabricks.net" in history_server_url) and "sparkui" in history_server_url
+        
+        if is_databricks:
+            cookies_file = config_dir / "databricks_cookies.txt"
+            console.print("")
+            console.print("[bold blue]Databricks Cookie Setup:[/bold blue]")
+            console.print("For Databricks, you need to copy cookies from your browser.")
+            console.print("")
+            console.print("Steps to get Databricks cookies:")
+            console.print("1. Open your Databricks workspace in your browser")
+            console.print("2. Navigate to the Spark UI for your application")
+            console.print("3. Open developer tools (F12 or right-click > Inspect)")
+            console.print("4. Go to the Network tab and click on any request")
+            console.print("5. Find the 'Cookie' header in the Request Headers")
+            console.print("6. Copy the entire cookie string")
+            console.print("")
+            console.print("Note: Make sure you're logged into Databricks and have access to the Spark UI.")
+            console.print("")
+        else:
+            cookies_file = config_dir / "raw_cookies.txt"
+            console.print("")
+            console.print("[bold blue]Browser Cookie Setup:[/bold blue]")
+            console.print("For browser mode, you need to copy cookies from your browser.")
+            console.print("")
+            console.print("Steps to get cookies:")
+            console.print("1. Open the Spark History Server in your browser")
+            console.print("2. Open developer tools (F12 or right-click > Inspect)")
+            console.print("3. Go to the Network tab and click on any request")
+            console.print("4. Find the 'Cookie' header in the Request Headers")
+            console.print("5. Copy the entire cookie string")
+            console.print("")
         
         if Confirm.ask("Would you like to enter cookies now?"):
             # Create empty file if it doesn't exist
@@ -250,22 +381,35 @@ def configure(
                     sys.exit(1)
             
             # Open the editor
-            console.print(f"\nOpening {editor} to edit cookies...")
-            console.print("Paste your cookies, save and exit the editor when done.")
+            if is_databricks:
+                console.print(f"\nOpening {editor} to edit Databricks cookies...")
+                console.print("Paste your Databricks cookies, save and exit the editor when done.")
+            else:
+                console.print(f"\nOpening {editor} to edit cookies...")
+                console.print("Paste your cookies, save and exit the editor when done.")
             console.print("")
             
             try:
                 subprocess.run([editor, str(cookies_file)], check=True)
                 if cookies_file.stat().st_size > 0:
-                    console.print(f"[green]✅ Cookies saved to {os.path.abspath(cookies_file)}[/green]")
+                    if is_databricks:
+                        console.print(f"[green]✅ Databricks cookies saved to {os.path.abspath(cookies_file)}[/green]")
+                    else:
+                        console.print(f"[green]✅ Cookies saved to {os.path.abspath(cookies_file)}[/green]")
                 else:
-                    console.print("[yellow]⚠️  Cookie file is empty. Browser mode authentication may fail.[/yellow]")
+                    if is_databricks:
+                        console.print("[yellow]⚠️  Cookie file is empty. Databricks mode authentication may fail.[/yellow]")
+                    else:
+                        console.print("[yellow]⚠️  Cookie file is empty. Browser mode authentication may fail.[/yellow]")
             except subprocess.CalledProcessError as e:
                 console.print(f"[red]Error: Failed to open editor: {str(e)}[/red]")
                 sys.exit(1)
         else:
-            console.print(f"\nYou can add cookies later by editing the file {os.path.abspath(cookies_file)}")
-            console.print("using your preferred text editor.")
+            console.print("")
+            console.print("[bold red]Configuration Incomplete[/bold red]")
+            console.print("Browser mode requires cookies for authentication.")
+            console.print("")
+            sys.exit(1)
     
     # Setup complete
     console.print("")
@@ -274,45 +418,34 @@ def configure(
     console.print("[bold green]==============================================[/bold green]")
     console.print("")
     
-    # Show next steps
-    console.print("You can now run the analyzer with:")
-    if connection_mode == "1":
-        if history_server_url != "http://localhost:18080/api/v1":
-            # Custom URL
-            console.print(f"  spark-analyzer --server-url '{history_server_url}'")
-            if cost_estimator_id:
-                console.print(f"  spark-analyzer --server-url '{history_server_url}' --cost-estimator-id '{cost_estimator_id}'")
-        else:
-            # Default URL
-            console.print("  spark-analyzer --local")
-            if cost_estimator_id:
-                console.print(f"  spark-analyzer --local --cost-estimator-id '{cost_estimator_id}'")
-    else:
-        console.print("  spark-analyzer --browser")
-        if cost_estimator_id:
-            console.print(f"  spark-analyzer --browser --cost-estimator-id '{cost_estimator_id}'")
-    
     # Ask if user wants to run now
     if Confirm.ask("\nWould you like to run the analyzer now?"):
         console.print("\n[blue]Running Spark Analyzer...[/blue]")
+        
+        save_local_mode = os.environ.get('SPARK_ANALYZER_SAVE_LOCAL_MODE') == '1'
+        save_local_flag = "--save-local " if save_local_mode else ""
+        
+        original_args = os.environ.get('SPARK_ANALYZER_ORIGINAL_ARGS', '')
+        original_args_str = f"{original_args} " if original_args else ""
+        
         if connection_mode == "1":
             if history_server_url != "http://localhost:18080/api/v1":
                 # Custom URL
                 if cost_estimator_id:
-                    os.system(f"spark-analyzer --server-url '{history_server_url}' --cost-estimator-id '{cost_estimator_id}'")
+                    os.system(f"spark-analyzer {save_local_flag}{original_args_str}--server-url '{history_server_url}' --cost-estimator-id '{cost_estimator_id}'")
                 else:
-                    os.system(f"spark-analyzer --server-url '{history_server_url}'")
+                    os.system(f"spark-analyzer {save_local_flag}{original_args_str}--server-url '{history_server_url}'")
             else:
                 # Default URL
                 if cost_estimator_id:
-                    os.system(f"spark-analyzer --local --cost-estimator-id '{cost_estimator_id}'")
+                    os.system(f"spark-analyzer {save_local_flag}{original_args_str}--local --cost-estimator-id '{cost_estimator_id}'")
                 else:
-                    os.system("spark-analyzer --local")
-        else:
+                    os.system(f"spark-analyzer {save_local_flag}{original_args_str}--local")
+        elif connection_mode == "2":
             if cost_estimator_id:
-                os.system(f"spark-analyzer --browser --cost-estimator-id '{cost_estimator_id}'")
+                os.system(f"spark-analyzer {save_local_flag}{original_args_str}--browser --cost-estimator-id '{cost_estimator_id}'")
             else:
-                os.system("spark-analyzer --browser")
+                os.system(f"spark-analyzer {save_local_flag}{original_args_str}--browser")
 
 @app.command()
 def show():
