@@ -5,13 +5,20 @@ import configparser
 import os
 import argparse
 import logging
-import pkg_resources
 import sys
 import time
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3.util.retry import Retry
+from .utils import print_error_box
 
-from .. import cli
+# Modern replacement for pkg_resources
+try:
+    from importlib.resources import files
+    MODERN_RESOURCES = True
+except ImportError:
+    # Fallback for older Python versions
+    import pkg_resources
+    MODERN_RESOURCES = False
 
 class APIClient:
     """Client for interacting with the server API."""
@@ -139,11 +146,20 @@ class APIClient:
             if hasattr(args, 'env') and args.env:
                 env_suffix = f"_{args.env}"
             
-            # Only check in configs directory
-            cookie_paths = [
-                os.path.join("configs", f"raw_cookies{env_suffix}.txt"),
-                os.path.join("configs", "raw_cookies.txt")
-            ]
+            is_databricks = ("databricks.com" in self.base_url and "sparkui" in self.base_url) or ("azuredatabricks.net" in self.base_url and "sparkui" in self.base_url)
+            
+            if is_databricks:
+                cookie_paths = [
+                    os.path.join("configs", f"databricks_cookies{env_suffix}.txt"),
+                    os.path.join("configs", "databricks_cookies.txt")
+                ]
+                cookie_type = "Databricks"
+            else:
+                cookie_paths = [
+                    os.path.join("configs", f"raw_cookies{env_suffix}.txt"),
+                    os.path.join("configs", "raw_cookies.txt")
+                ]
+                cookie_type = "browser"
             
             cookie_found = False
             file_exists_but_empty = False
@@ -159,25 +175,28 @@ class APIClient:
                             if non_comment_lines:
                                 self.raw_cookies = '\n'.join(non_comment_lines)
                                 cookie_found = True
-                                logging.debug(f"Using cookies from: {path}")
+                                logging.debug(f"Using {cookie_type} cookies from: {path}")
                                 break
                             else:
                                 file_exists_but_empty = True
                     except Exception as e:
-                        logging.error(f"Error reading cookie file {path}: {str(e)}")
+                        logging.error(f"Error reading {cookie_type} cookie file {path}: {str(e)}")
                         continue
                     
             if not cookie_found:
                 if file_exists_but_empty:
-                    print("⚠️  Cookie file found but contains no actual cookies: Browser mode authentication may fail.")
+                    print(f"⚠️  {cookie_type.capitalize()} cookie file found but contains no actual cookies: {cookie_type.capitalize()} mode authentication may fail.")
                     print("   Edit the file with your browser cookies:")
                     found_path = next((p for p in cookie_paths if os.path.exists(p)), None)
                     if found_path:
                         print(f"   {os.path.abspath(found_path)}")
                 else:
-                    print("⚠️  Cookie file not found: Browser mode authentication may fail.")
+                    print(f"⚠️  {cookie_type.capitalize()} cookie file not found: {cookie_type.capitalize()} mode authentication may fail.")
                     print("   To use browser mode, create the cookie file at:")
-                    print("   configs/raw_cookies.txt")
+                    if is_databricks:
+                        print("   configs/databricks_cookies.txt")
+                    else:
+                        print("   configs/raw_cookies.txt")
                     print("   Then edit the file with your browser cookies")
             else:
                 try:
@@ -198,40 +217,61 @@ class APIClient:
                         self.cookie_dict[key.strip()] = value.strip()
                     
                     if not self.cookie_dict:
-                        logging.warning("Failed to parse cookies. Cookie format may be invalid.")
-                        print("⚠️  Warning: Failed to parse cookies. Cookie format may be invalid.")
-                        print("   Please ensure you've copied the entire Cookie header from your browser's dev tools")
-                        print("   For AWS EMR, make sure you're logged in to the EMR console before copying cookies")
+                        logging.warning(f"Failed to parse {cookie_type} cookies. Cookie format may be invalid.")
                     else:
-                        logging.info(f"Successfully parsed {len(self.cookie_dict)} cookies")
+                        logging.info(f"Successfully parsed {len(self.cookie_dict)} {cookie_type} cookies")
                 except Exception as e:
-                    logging.error(f"Error parsing cookies: {str(e)}")
-                    print("⚠️  Warning: Error parsing cookies. Please check the cookie file format.")
-                    print("   For AWS EMR, copy the entire Cookie header from the Network tab in dev tools")
+                    logging.error(f"Error parsing {cookie_type} cookies: {str(e)}")
         
         self.headers = self.get_headers()
         
-        keyword_paths = [
-            os.path.join("resources", "hoodie_keywords.json"),
-            pkg_resources.resource_filename("spark_analyzer", os.path.join("resources", "hoodie_keywords.json"))
-        ]
-        
-        keywords_found = False
-        for path in keyword_paths:
-            if os.path.exists(path):
+        self.workflow_type_keywords = {}
+        try:
+            # Try to load workflow type keywords
+            keyword_paths = [
+                os.path.join("resources", "workflow_type_keywords.json"),
+            ]
+            
+            # Add package resource path using modern or legacy approach
+            if MODERN_RESOURCES:
                 try:
-                    with open(path, "r") as f:
-                        self.hoodie_keywords = json.load(f)
-                    keywords_found = True
-                    break
-                except Exception as e:
-                    logging.error(f"Error reading keywords file {path}: {str(e)}")
-                    continue
-                
-        if not keywords_found:
-            logging.error("Hoodie keywords file not found. Analysis will be incomplete.")
-            print("⚠️  Warning: Hoodie keywords file not found. Stage type classification will be limited.")
-            self.hoodie_keywords = {"hoodie_identifiers": [], "scan_keywords": [], "transform_keywords": [], "load_keywords": []}
+                    resource_path = files("spark_analyzer").joinpath("resources", "workflow_type_keywords.json")
+                    keyword_paths.append(str(resource_path))
+                except Exception:
+                    pass  # Fallback to local path only
+            else:
+                try:
+                    keyword_paths.append(pkg_resources.resource_filename("spark_analyzer", os.path.join("resources", "workflow_type_keywords.json")))
+                except Exception:
+                    pass  # Fallback to local path only
+            
+            keywords_found = False
+            for path in keyword_paths:
+                if os.path.exists(path):
+                    try:
+                        with open(path, "r") as f:
+                            self.workflow_type_keywords = json.load(f)
+                        keywords_found = True
+                        break
+                    except Exception as e:
+                        logging.error(f"Error reading keywords file {path}: {str(e)}")
+                        continue
+                    
+            if not keywords_found:
+                logging.error("Workflow type keywords file not found. Analysis will be incomplete.")
+                print("⚠️  Warning: Workflow type keywords file not found. Stage type classification will be limited.")
+                self.workflow_type_keywords = {
+                    "merge_write": [], "insert_write": [], "scan": [], 
+                    "transform": [], "join": [], "indexing": [], 
+                    "metadata": [], "clustering_compaction": []
+                }
+        except Exception as e:
+            logging.error(f"Error loading workflow type keywords: {str(e)}")
+            self.workflow_type_keywords = {
+                "merge_write": [], "insert_write": [], "scan": [], 
+                "transform": [], "join": [], "indexing": [], 
+                "metadata": [], "clustering_compaction": []
+            }
         
     def get_headers(self) -> Dict[str, Any]:
         """Get the headers for the API request."""
@@ -268,7 +308,6 @@ class APIClient:
             url = url[:-1]
         
         logging.debug(f"Normalizing URL: {url}")
-            
         if url.endswith('/api/v1'):
             logging.debug(f"URL already has /api/v1 suffix: {url}")
             return url
@@ -298,30 +337,50 @@ class APIClient:
             
             if hasattr(self, 'cookie_dict') and self.cookie_dict:
                 kwargs["cookies"] = self.cookie_dict
+                if "databricks.com" in url:
+                    kwargs["headers"] = {
+                        "Accept": "application/json",
+                        "Content-Type": "application/json",
+                        "User-Agent": "Spark-Analyzer/1.0"
+                    }
+                
+                if hasattr(self, 'args') and self.args and hasattr(self.args, 'debug') and self.args.debug:
+                    logging.debug(f"Using cookies: {list(self.cookie_dict.keys())}")
+                    logging.debug(f"Cookie count: {len(self.cookie_dict)}")
             else:
                 kwargs["headers"] = self.headers if self.headers else {}
+                if hasattr(self, 'args') and self.args and hasattr(self.args, 'debug') and self.args.debug:
+                    logging.debug("No cookies found, using headers only")
                 
             response = self._request_with_retry(self.session.get, url, **kwargs)
             response.raise_for_status()
             
+            if hasattr(self, 'args') and self.args and hasattr(self.args, 'debug') and self.args.debug:
+                logging.debug(f"Response status: {response.status_code}")
+                logging.debug(f"Response headers: {dict(response.headers)}")
+                logging.debug(f"Response content (first 500 chars): {response.text[:500]}")
+            
             try:
                 return response.json()
             except json.JSONDecodeError as e:
                 logging.error(f"Invalid JSON response from {url}: {str(e)}")
+                if hasattr(self, 'args') and self.args and hasattr(self.args, 'debug') and self.args.debug:
+                    logging.error(f"Response status code: {response.status_code}")
+                    logging.error(f"Response headers: {dict(response.headers)}")
+                    logging.error(f"Response content: {response.text}")
                 raise
             
         except requests.exceptions.ConnectionError as e:
             if hasattr(self, 'args') and self.args and hasattr(self.args, 'debug') and self.args.debug:
                 logging.error(f"Connection error for URL {url}: {e}")
             
-            cli.print_error_box(
+            print_error_box(
                 "CONNECTION ERROR",
                 "Could not connect to the Spark History Server",
                 "1. Check that the server is running and accessible\n" +
                 "2. Verify your network connection\n" +
                 "3. Check your server URL configuration\n" +
-                f"4. Try accessing {self.original_url} in your browser\n" +
-                "5. If you know the application ID, use --app_id option"
+                f"4. Try accessing {self.original_url} in your browser\n"
             )
             
             sys.exit(1)
@@ -329,7 +388,7 @@ class APIClient:
             if hasattr(self, 'args') and self.args and hasattr(self.args, 'debug') and self.args.debug:
                 logging.error(f"Request timeout for {endpoint}: {e}")
             
-            cli.print_error_box(
+            print_error_box(
                 "CONNECTION TIMEOUT",
                 f"The request to the Spark History Server timed out after {self.timeout} seconds",
                 "1. Try running the command again later\n" +
@@ -358,8 +417,7 @@ class APIClient:
                 title = f"SPARK HISTORY SERVER NOT FOUND"
                 message = f"The requested resource was not found: {endpoint}"
                 help_text = "1. Verify your Spark History Server URL is correct\n" + \
-                           "2. Check that the application ID or stage ID is correct\n" + \
-                           "3. Try using --app_id to specify an application directly"
+                           "2. Check that the application ID or stage ID is correct"
             elif status_code == 429:
                 title = f"TOO MANY REQUESTS ({status_code})"
                 message = "The server is rate limiting your connections"
@@ -377,20 +435,51 @@ class APIClient:
                 help_text = "1. Try again later\n" + \
                            "2. Check your server URL and parameters"
             
-            cli.print_error_box(title, message, help_text)
+            print_error_box(title, message, help_text)
             
             sys.exit(1)
         except json.JSONDecodeError:
             logging.error(f"JSON decode error for {endpoint}")
             
-            cli.print_error_box(
-                "INVALID SERVER RESPONSE",
-                "The server returned a non-JSON response",
-                "1. Verify your server URL configuration\n" +
-                "2. Make sure you're connecting to the API endpoint, not the web UI\n" +
-                "3. Try adding or removing '/api/v1' from your URL\n" +
-                f"4. Current URL: {self.original_url}"
-            )
+            # Determine the type of error based on the URL
+            user_url = self.original_url if hasattr(self, 'original_url') else "unknown"
+            
+            if "console.aws.amazon.com" in user_url or "aws.amazon.com" in user_url:
+                print_error_box(
+                    "AWS CONSOLE URL DETECTED",
+                    f"You entered an AWS console URL: {user_url}",
+                    "1. This is not a Spark History Server URL\n"
+                    "2. You need the Spark History Server URL from your EMR cluster\n"
+                    "3. Find it in the EMR console under your cluster's 'Application history' tab\n"
+                    "4. The URL should look like: http://your-cluster-master:18080"
+                )
+            elif "databricks.com" in user_url and "sparkui" in user_url:
+                print_error_box(
+                    "DATABRICKS SPARK UI URL DETECTED",
+                    f"You entered an incorrect Databricks Spark UI URL",
+                    "1. This is a web UI URL, not an API URL\n"
+                    "2. Copy the entire Spark UI URL you see in your browser\n"
+                    "3. Example format: https://dbc-xxx.cloud.databricks.com/compute/sparkui/application-id/driver-id?o=workspace-id\n"
+                    "4. Make sure you have valid Databricks cookies configured"
+                )
+            elif "localhost" in user_url or "127.0.0.1" in user_url:
+                print_error_box(
+                    "LOCAL SPARK HISTORY SERVER ERROR",
+                    f"Could not connect to local Spark History Server: {user_url}",
+                    "1. Make sure Spark History Server is running on your local machine\n"
+                    "2. Check if the port is correct (default is 18080)\n"
+                    "3. Try accessing the URL in your browser first\n"
+                    "4. If using a different port, update your URL accordingly"
+                )
+            else:
+                print_error_box(
+                    "INVALID SERVER RESPONSE",
+                    f"The server at {user_url} returned a non-JSON response",
+                    "1. Verify you're connecting to a Spark History Server API endpoint\n"
+                    "2. Make sure you're not connecting to a web UI (use --browser flag for web UIs)\n"
+                    "3. Check if the server URL is correct\n"
+                    "4. Try accessing the URL in your browser to verify it's accessible"
+                )
             
             sys.exit(1)
     
@@ -487,23 +576,6 @@ class APIClient:
             logging.error(f"Failed to get stages for {app_id}: {str(e)}")
             raise
     
-    def is_indexing_candidate(self, stage):
-        """Check if a stage is an RLI (Record Level Indexing) candidate."""
-        if isinstance(stage, list):
-            if not stage:
-                return False
-            stage = stage[0]
-        
-        description = stage.get("description", "")
-        if not description:
-            return False
-            
-        for keyword in self.hoodie_keywords.get("rli_keywords", []):
-            if keyword.lower() in description.lower():
-                return True
-                
-        return False
-    
     def get_stage(self, app_id: str, stage_id: str) -> Dict[str, Any]:
         """Get a specific stage from an application."""
         return self.get_stage_details(app_id, stage_id) 
\ No newline at end of file
