@@ -6,7 +6,15 @@ import json
 import time
 import random
 from typing import List, Dict, Any, Optional
-import pkg_resources
+
+# Modern replacement for pkg_resources
+try:
+    from importlib.resources import files
+    MODERN_RESOURCES = True
+except ImportError:
+    # Fallback for older Python versions
+    import pkg_resources
+    MODERN_RESOURCES = False
 
 class S3Uploader:
     DEFAULT_API_BASE_URL = "https://api.onehouse.ai"
@@ -29,10 +37,25 @@ class S3Uploader:
         self.args = args
         
         config_paths = [
-            pkg_resources.resource_filename("spark_analyzer", os.path.join("lib", "configs", config_file)),
+        ]
+        
+        if MODERN_RESOURCES:
+            try:
+                resource_path = files("spark_analyzer").joinpath("lib", "configs", config_file)
+                config_paths.append(str(resource_path))
+            except Exception:
+                pass  
+        else:
+            try:
+                config_paths.append(pkg_resources.resource_filename("spark_analyzer", os.path.join("lib", "configs", config_file)))
+            except Exception:
+                pass  
+        
+        # Add local paths
+        config_paths.extend([
             os.path.join("lib", "configs", config_file),
             os.path.join(os.path.expanduser("~"), ".spark_analyzer", "configs", config_file)
-        ]
+        ])
         
         config_found = False
         self.config_path_used = None
